@@ -1,7 +1,10 @@
-obs.vs.model <- function(glm.joint, plot.disp = FALSE, ...){
+obs.vs.model <- function(x.joint, plot.disp = FALSE, ...){
+
+  warning("Package JointGLM is outdated. Please use the JointModeling packgage.\n")
+  
   ##Plot observations functions of predicted values
 
-  ##glm.joint  : A list with two component. Both are objects of class
+  ##x.joint  : A list with two component. Both are objects of class
   ##             ``glm'' corresponding to the mean and dispersion
   ##             respectively.
   ##plot.disp : Logical. If ``TRUE'' error bar - i.e. +/- standard
@@ -9,19 +12,19 @@ obs.vs.model <- function(glm.joint, plot.disp = FALSE, ...){
   ##...       : Optional arguments to be passed to ``plot'' and
   #             ``abline'' functions.
 
-  glm.mean <- glm.joint$glm.mean
-  glm.disp <- glm.joint$glm.disp
+  mod.mean <- x.joint$mod.mean
+  mod.disp <- x.joint$mod.disp
   
-  Model <- glm.mean$fitted
-  Obs <- glm.mean$y
+  Model <- mod.mean$fitted
+  Obs <- mod.mean$y
   
   plot(Model, Obs, ...)
   abline(a=0, b=1, ...)
 
   if (plot.disp){
-    fct.var <- glm.mean$family$variance      #The variance function
+    fct.var <- mod.mean$family$variance      #The variance function
     choice <- identify(x = Model, y = Obs, plot = FALSE)
-    ecart.type <- sqrt(glm.disp$fitted * fct.var(glm.mean$fitted)) 
+    ecart.type <- sqrt(mod.disp$fitted * fct.var(mod.mean$fitted)) 
     arrows(Model[choice], Obs[choice], Model[choice] +
            ecart.type[choice], Obs[choice],
            angle= 90, length= 0.05)
@@ -32,19 +35,22 @@ obs.vs.model <- function(glm.joint, plot.disp = FALSE, ...){
 }
 
 
-rstand.vs.linpred <- function(glm, smooth = TRUE, ...){
+rstand.vs.linpred <- function(x, smooth = TRUE, ...){
+
+  warning("Package JointGLM is outdated. Please use the JointModeling packgage.\n")
+  
   ##Plot standardized residuals functions of  the linear
   ##predictor
 
-  ##glm    : Object of class ``glm''
+  ##x    : A fitted joint model object
   ##smooth : Logical. If ``TRUE'' response surface is estimated
   ##         thanks to the ``lowess'' function. It is helpfull
   ##         to detect departure from the model.
   ##...    : Optional arguments to be passed to the
   ##         ``plot'' and ``abline'' functions.
 
-  res.stand <- residuals(glm, 'deviance') / sqrt(1 - hat.glm(glm))
-  lin.pred <- glm$linear.predictors
+  res.stand <- residuals(x, 'deviance') / sqrt(1 - hat.glm(x))
+  lin.pred <- x$linear.predictors
   plot(lin.pred, res.stand, ...)
   abline( h =0, ...)
 
@@ -54,11 +60,14 @@ rstand.vs.linpred <- function(glm, smooth = TRUE, ...){
   }
 }
 
-res.vs.explvar <- function(glm, var, res = 'standard',
+res.vs.explvar <- function(x, var, res = 'standard',
                            smooth = TRUE, ...){
+
+  warning("Package JointGLM is outdated. Please use the JointModeling packgage.\n")
+  
   ##Plot residuals functions of an explanatory variable
 
-  ##glm    : Object of class ``glm''
+  ##x    : Object of class ``glm''
   ##var    : Character. The name of the explanatory variable
   ##res    : Should be 'standard', 'student', 'brut'
   ##         The residual type chosen.
@@ -68,16 +77,16 @@ res.vs.explvar <- function(glm, var, res = 'standard',
   ##...    : Optional arguments to be passed to 
   ##         ``plot'' and ``abline'' functions.
 
-  if (!any(names(glm$data) == var))
+  if (!any(names(x$data) == var))
     stop("Invalid explanatory variable !")
   else
-    var <- as.vector(glm$data[[var]])
+    var <- as.vector(x$data[[var]])
 
-  res <- switch(res, 'standard' = residuals(glm,'deviance') /
-                sqrt(1 - hat.glm(glm)),
-                'student' = residuals(glm, 'deviance') /
-                sqrt(summary(glm)$dispersion*(1-hat.glm(glm))),
-                'brut' = residuals(glm, 'deviance'))
+  res <- switch(res, 'standard' = residuals(x,'deviance') /
+                sqrt(1 - hat.glm(x)),
+                'student' = residuals(x, 'deviance') /
+                sqrt(summary(x)$dispersion*(1-hat.glm(x))),
+                'brut' = residuals(x, 'deviance'))
   plot(var, res, ...)
   abline( h = 0, ...)
 
@@ -86,11 +95,14 @@ res.vs.explvar <- function(glm, var, res = 'standard',
   }
 }
   
-absres.vs.fitted <- function(glm, res = 'standard',
+absres.vs.fitted <- function(x, res = 'standard',
                              smooth = TRUE, ...){
+
+  warning("Package JointGLM is outdated. Please use the JointModeling packgage.\n")
+  
   ##Plot absolute residuals functions of predicted values
 
-  ##glm    : Object of class``glm''
+  ##x    : Object of class``glm''
   ##res    : Should be 'standard', 'student', 'brut'
   ##         The residual type chosen.
   ##smooth : Logical. . If ``TRUE'' response surface is estimated
@@ -100,13 +112,13 @@ absres.vs.fitted <- function(glm, res = 'standard',
   ##         function.
 
 
-  res <- switch(res, 'standard' = residuals(glm,'deviance') /
-                sqrt(1 - hat.glm(glm)),
-                'student' = residuals(glm, 'deviance') /
-                sqrt(summary(glm)$dispersion*(1-hat.glm(glm))),
-                'brut' = residuals(glm, 'deviance'))
+  res <- switch(res, 'standard' = residuals(x,'deviance') /
+                sqrt(1 - hat.glm(x)),
+                'student' = residuals(x, 'deviance') /
+                sqrt(summary(x)$dispersion*(1-hat.glm(x))),
+                'brut' = residuals(x, 'deviance'))
 
-  fitted <- glm$fitted
+  fitted <- x$fitted
 
   plot(fitted, abs(res), ...)
 
@@ -115,30 +127,33 @@ absres.vs.fitted <- function(glm, res = 'standard',
   }
 }
 
-adjvar.vs.linpred <- function(glm, smooth = TRUE, ...){
+adjvar.vs.linpred <- function(x, smooth = TRUE, ...){
+
+  warning("Package JointGLM is outdated. Please use the JointModeling packgage.\n")
+  
   ##Plot the adjusted dependent variable functions of
   ##the linear predictor.
 
-  ##glm    : Object of class``glm''
+  ##x    : Object of class``glm''
   ##smooth : Logical. . If ``TRUE'' response surface is estimated
   ##         thanks to the ``lowess'' function. It is helpfull to
   ##         detect departure from the model.
   ##...    : Optional arguments to be passed to the ``plot''
   ##         function.
 
-  link <- glm$family$linkfun
-  y <- glm$y
-  lin.pred <- glm$linear.predictors
+  link <- x$family$linkfun
+  y <- x$y
+  lin.pred <- x$linear.predictors
   z <- link(y)
 
-  link <- glm$family$link
+  link <- x$family$link
   switch(link,
-         'identity' = { z <- z + y - glm$fitted },
-         'log' = { z <- z + (y - glm$fitted) / glm$fitted },
-         'inverse' = { z <- z - (y - glm$fitted) / glm$fitted^2 },
-         'logit' = { z <- z + (y - glm$fitted) / (1 - glm$fitted)^2 },
-         'sqrt' = { z <- z + 2 * (y - glm$fitted) / sqrt(glm$fitted) },
-         '1/mu^2' = { z <- z - 2 * (y - glm$fitted) / glm$fitted^3 },
+         'identity' = { z <- z + y - x$fitted },
+         'log' = { z <- z + (y - x$fitted) / x$fitted },
+         'inverse' = { z <- z - (y - x$fitted) / x$fitted^2 },
+         'logit' = { z <- z + (y - x$fitted) / (1 - x$fitted)^2 },
+         'sqrt' = { z <- z + 2 * (y - x$fitted) / sqrt(x$fitted) },
+         '1/mu^2' = { z <- z - 2 * (y - x$fitted) / x$fitted^3 },
          'probit' = stop('Not implemented yet !!!'),
          'cloglog' = stop('Not implemented yet !!!')
          )
@@ -153,15 +168,23 @@ adjvar.vs.linpred <- function(glm, smooth = TRUE, ...){
 
 }
 
-summplot.glm <- function(glm, var = NULL, res = 'standard',
-                         which = 1:5,
-                         ask = nb.fig < length(which) &&
-                         dev.interactive(), smooth = TRUE,
-                         ...){
+plot.joint <- function(x, comp = "mean", var = NULL,
+                       res = 'standard', which = 1:5,
+                       ask = nb.fig < length(which) &&
+                       dev.interactive(), smooth = TRUE, ...){
+
+  warning("Package JointGLM is outdated. Please use the JointModeling packgage.\n")
+  
   if (!is.numeric(which) || any(which < 1) || any(which > 5)) 
         stop("`which' must be in 1:5")
   if (is.null(var) && any(which == 2))
     stop("Select an explanatory variable please.")
+
+  if (comp == "mean")
+    x <- x$mod.mean
+
+  else
+    x <- x$mod.disp
   
   show <- rep(FALSE, 5)
   show[which] <- TRUE
@@ -172,31 +195,34 @@ summplot.glm <- function(glm, var = NULL, res = 'standard',
     on.exit(par(op))
   }
   if (show[1]) {
-    rstand.vs.linpred(glm, smooth = smooth, ...)
+    rstand.vs.linpred(x, smooth = smooth, ...)
   }
   if (show[2]) {
-    res.vs.explvar(glm, var, res, smooth = smooth, ...)
+    res.vs.explvar(x, var, res, smooth = smooth, ...)
   }
   if (show[3]) {
-    absres.vs.fitted(glm, res, smooth = smooth, ...)
+    absres.vs.fitted(x, res, smooth = smooth, ...)
   }
   if (show[4]) {
-    adjvar.vs.linpred(glm, smooth = smooth, ...)
+    adjvar.vs.linpred(x, smooth = smooth, ...)
   }
   if (show[5]) {
-    qqglm(glm, ...)
+    qqglm(x, ...)
   }
 }
 
-qqglm <- function(glm, ...){
+qqglm <- function(x, ...){
+
+  warning("Package JointGLM is outdated. Please use the JointModeling packgage.\n")
+  
   ##Produce a QQ-plot for the studentized residuals
 
-  ##glm    : Object of class``glm''
-  ##...    : Optional arguments to be passed to the ``qqnorm''
-  ##         function.
+  ##x    : A fitted joint model object
+  ##...  : Optional arguments to be passed to the ``qqnorm''
+  ##       function.
 
-  res <- residuals(glm, 'deviance') /
-                sqrt((1-hat.glm(glm)) * summary(glm)$dispersion)
+  res <- residuals(x, 'deviance') /
+                sqrt((1-hat.glm(x)) * summary(x)$dispersion)
                 
   qqnorm(res, ...)
   abline(a = 0, b = 1, ...)
